import unittest
from datetime import datetime, timedelta

from ashe import today, yesterday


class DateTest(unittest.TestCase):
    def setUp(self) -> None:
        self.today = str(datetime.today().date())
        self.yesterday = str(datetime.today().date() - timedelta(days=1))
        self.today_date = datetime.fromisoformat(self.today).date()
        self.yesterday_date = datetime.fromisoformat(self.yesterday).date()

    def test_date(self) -> None:
        self.assertEqual(self.today, today())
        self.assertEqual(self.today_date, today("date"))
        self.assertEqual(self.yesterday, yesterday())
        self.assertEqual(self.yesterday_date, yesterday("date"))


if __name__ == "__main__":
    unittest.main()



from datetime import datetime, timedelta


def today(date_type="str"):
    _today = datetime.today().date()
    if date_type == "str":
        _today = str(_today)
    return _today


def yesterday(date_type="str"):
    _yesterday = datetime.today().date() - timedelta(days=1)
    if date_type == "str":
        _yesterday = str(_yesterday)
    return _yesterday



from ._dict import merge, remove
from ._list import reverse
from ._sys import size
from ._str import find
from ._date import today, yesterday
from ._file import read, write


__version__ = "0.0.5"

__all__ = [
    "merge",
    "remove",
    "reverse",
    "size",
    "find",
    "read",
    "write",
    "today",
    "yesterday"
]
